macro_rules! impl_collection_type {
($ty:ident<$generic:ident> => Array) => { ... };
}Expand description
Implements the Type trait for a generic collection type.
This macro helps implement the Type trait for generic collection types like Vec, HashSet, etc., that contain elements of a type implementing Type.
Examples
ⓘ
// For array-like collections
impl_collection_type!(Vec<T> => Array);
impl_collection_type!(HashSet<T> => Array);
// For map-like collections (with string keys)
impl_map_type!(HashMap<String, V> => Map);